Learn R Programming

rtdists (version 0.12-0)

rtdists-package: rtdists: Response Time Distributions

Description

Provides response time distributions (density/PDF, distribution function/CDF, quantile function, and random generation): (a) Ratcliff diffusion model (Ratcliff & McKoon, 2008, <doi:10.1162/neco.2008.12-06-420>) based on C code by Andreas and Jochen Voss and (b) linear ballistic accumulator (LBA; Brown & Heathcote, 2008, <doi:10.1016/j.cogpsych.2007.12.002>) with different distributions underlying the drift rate, and (c) racing diffusion model (RDM; Tillman, Van Zandt, & Logan, 2020, <doi:10.3758/s13423-020-01719-6>).

Arguments

Author

Henrik Singmann, Scott Brown, Matthew Gretton, Andrew Heathcote, Kianté Fernandez, with contributions from Andreas Voss, Jochen Voss, Andrew Terry, Trisha Van Zandt, Gabriel Tillman

See Also