Learn R Programming

rtdists (version 0.11-6)

rtdists-package: The rtdists Package

Description

Response Time Distributions.

Arguments

Author

Henrik Singmann, Scott Brown, Matthew Gretton, Andrew Heathcote, with contributions from Andreas Voss, Jochen Voss, Andrew Terry

Details

Package:rtdists
Type:Package
Version:0.8-3
Date:2018-06-23
Depends:R (>= 3.0.0)
License:GPL (>=3)
URL:https://github.com/rtdists/rtdists/

Provides response time distributions (density/PDF, distribution function/CDF, quantile function, and random generation): (a) Ratcliff diffusion model (Ratcliff & McKoon, 2008, <doi:10.1162/neco.2008.12-06-420>) based on C code by Andreas and Jochen Voss and (b) linear ballistic accumulator (LBA; Brown & Heathcote, 2008, <doi:10.1016/j.cogpsych.2007.12.002>) with different distributions underlying the drift rate.

See Also